import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(["apple", "orange", "lemon"])
	.range(["crimson", "orange", "gold"]);

const radiusScale = scaleOrdinal()
	.domain(["apple", "orange", "lemon"])
	.range([50, 40, 30])


export const fruitBowl = (selection, props) => {
  const { 
    fruits, 
    height, 
    onClick,
  	selectedFruit
  } = props;
  const bowl = selection.selectAll("rect")
  	.data([0])
  	.enter().append("rect")
  		.attr("width", 920)
  		.attr("height", 300)
  		.attr("y", 100)
  		.attr("rx", 150)
  		.attr("fill", "seashell")
  		.attr("stroke", "brown")
  	
  const groups = selection.selectAll("g")
  	.data(fruits, d => d.id);
  const groupsEnter = groups.enter().append("g")
  groupsEnter.merge(groups)
  		.attr("transform", (d, i) => `translate(${i * 180 + 100},${height / 2})`)  
    
  groups.exit()
  	.select("circle")
  	.transition().duration(1000)
  		.attr("r", 0)  	
  groups.exit()
  	.transition().duration(1000)
  	.remove()
   
  groupsEnter.append("circle")
  	.attr("r", 0)
  	.merge(groups.select("circle"))
  	.on("click", d => onClick(d.id))
  	.transition().duration(1000)
  		.attr('fill', d => colorScale(d.type))
  		.attr("stroke", d => 
            d.id === selectedFruit
           	? "black"
           	: "none"
           )
  		.attr("stroke-width", 5)
  		.attr('r', d => radiusScale(d.type));
    
  groupsEnter.append("text")
  	.merge(groups.select("text"))
  		.attr("y", 100)
  		.text(d => d.type)  
}